@@ -79,54 +79,6 @@ def send_email(config, key, data={}, attachments=[],
         log.debug("skipping email of type '%s' per config", key)
 
 
-# TODO: deprecate / remove this (used only for tailbone preview?)
-def deliver_message(config, key, msg, recipients=UNSPECIFIED):
-    """
-    Deliver an email message using the given SMTP configuration.
-    """
-    if recipients is UNSPECIFIED:
-        recips = set()
-        to = msg.get_all('To')
-        if to:
-            recips = recips.union(set(to))
-        cc = msg.get_all('Cc')
-        if cc:
-            recips = recips.union(set(cc))
-        bcc = msg.get_all('Bcc')
-        if bcc:
-            recips = recips.union(set(bcc))
-    else:
-        recips = set(recipients)
-    if not recips:
-        raise RuntimeError("No recipients for email: {0}".format(repr(msg)))
-
-    server = config.get('rattail.mail', 'smtp.server', default='localhost')
-    username = config.get('rattail.mail', 'smtp.username')
-    password = config.get('rattail.mail', 'smtp.password')
-
-    if config.getbool('rattail.mail', 'send_feedback_only', usedb=False, default=False):
-        send = key == 'user_feedback'
-    else:
-        send = config.getbool('rattail.mail', 'send_emails', usedb=False, default=True)
-
-    if send:
-
-        log.debug("attempting to send mail of type: %s", key)
-        log.debug("connecting to server: %s", server)
-        session = smtplib.SMTP(server)
-        if username and password:
-            result = session.login(username, password)
-            log.debug("login() result is: %s", repr(result))
-
-        result = session.sendmail(msg['From'], recips, msg.as_string())
-        log.debug("sendmail() result is: %s", repr(result))
-        session.quit()
-        return True
-
-    log.debug("config says no emails for '%s', but would have sent one to: %s", key, recips)
-    return False
-
-
 class EmailHandler(object):
     """
     Base class and default implementation for email handlers.
@@ -231,17 +183,30 @@ class EmailHandler(object):
         """
         if recipients is UNSPECIFIED:
             recips = set()
-            to = self.config.parse_list(msg['To'])
+
+            # nb. we use original recip lists, contained in X_RATTAIL
+            # headers, instead of the simple strings which e.g. the
+            # To: header contains.  but we also then remove custom
+            # headers b/c they don't belong in the final msg
+
+            to = msg['X_RATTAIL_TO']
+            del msg['X_RATTAIL_TO']
             if to:
                 recips = recips.union(set(to))
-            cc = self.config.parse_list(msg['Cc'])
+
+            cc = msg['X_RATTAIL_CC']
+            del msg['X_RATTAIL_CC']
             if cc:
                 recips = recips.union(set(cc))
-            bcc = self.config.parse_list(msg['Bcc'])
+
+            bcc = msg['X_RATTAIL_BCC']
+            del msg['X_RATTAIL_BCC']
             if bcc:
                 recips = recips.union(set(bcc))
+
         else:
             recips = set(recipients)
+
         if not recips:
             raise RuntimeError("No recipients for email: {0}".format(repr(msg)))
 
@@ -610,12 +575,18 @@ class Email(object):
                 bcc = self.get_recips('bcc')
         if not (to or cc or bcc):
             raise exceptions.RecipientsNotFound(self.key)
+
+        # nb. we preserve the original lists within X_RATTAIL headers,
+        # for easier SMTP sending later on
         if to:
             msg['To'] = ', '.join(to)
+            msg['X_RATTAIL_TO'] = to
         if cc:
             msg['Cc'] = ', '.join(cc)
+            msg['X_RATTAIL_CC'] = cc
         if bcc:
             msg['Bcc'] = ', '.join(bcc)
+            msg['X_RATTAIL_BCC'] = bcc
 
 
 # NOTE: this bit of magic was stolen from Django
