@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -202,8 +202,8 @@ class ProblemReportHandler(object):
         """
         Render the given timestamp, localizing if necessary.
         """
-        time = localtime(self.config, time, from_utc=from_utc)
-        return str(time)
+        time = self.app.localtime(time, from_utc=from_utc)
+        return self.app.render_datetime(time)
 
     def get_global_email_context(self, **kwargs):
         """
