@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -40,6 +40,13 @@ class Transaction(model.TransactionBase, model.Base):
     """
 
 
+class TransactionOrderMarker(model.TransactionOrderMarkerBase, model.Base):
+    """
+    Represents a "customer order xref" for a transaction.
+    """
+    __txn_class__ = Transaction
+
+
 class TransactionItem(model.TransactionItemBase, model.Base):
     """
     Represents a line item within a transaction.
